#
# spec file for package python-sphinx-jsonschema
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-sphinx-jsonschema
Version:        1.19.1
Release:        1.6
Summary:        Sphinx extension to display JSON Schema
License:        GPL-3.0-only
URL:            https://github.com/lnoor/sphinx-jsonschema
# Tarballs from pypi.org are missing license files
Source:         https://github.com/lnoor/sphinx-jsonschema/archive/refs/tags/v.%{version}.tar.gz#/sphinx-jsonschema-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PyYAML
Requires:       python-docutils
Requires:       python-jsonpointer
Requires:       python-requests
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module docutils}
BuildRequires:  %{python_module jsonpointer}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests}
# /SECTION
%python_subpackages

%description
Sphinx extension to display JSON Schema.

%prep
%setup -q -n sphinx-jsonschema-v.%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# The tests don't actually properly execute
# see upstream https://github.com/lnoor/sphinx-jsonschema/issues/56
#%%pytest

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/*

%changelog
* Sun Jan 14 2024 Dirk Müller <dmueller@suse.com>
- update to 1.19.1:
  * load a schema from a Python dict or object (or actually any
    Python entity with a ``__str__`` method.).
  * with JSON Pointer the ``:pass_unmodified:`` option is included.
  * fixed a bug escaping backspaces.
  * ``:hide_key:`` directive option.
    This option allows you to hide certain keys, specified by a JSON
    Path specification, to be excluded from rendering.
  * added the ``:encoding:`` directive option.
* Mon Apr 19 2021 Matthias Fehring <buschmann23@opensuse.org>
- Update to 1.16.8:
  * Improved rendering of string values
* Tue Mar 16 2021 Matthias Fehring <buschmann23@opensuse.org>
- Update to 1.16.7:
  * Fixed: Renders "null" default value as "None"
- Changes from 1.16.6:
  * Bug fixes
- Changes from 1.16.5:
  * Fixes auto reference without title
- Changes from 1.16.4:
  * Introduces the :lift_title: directive option suggested by ankostis.
  * Fixed a bug in rendering the items attribute of the array type
- Changes from 1.16.3:
  * Fixed bugs rendering the default and examples keywords.
- Changes from 1.16.2:
  * Introduced the configuration entry jsonschema_options setting
    default values for the directive options introduced in 1.16.
    The options now can accept a parameter to explicitly turn the
    option on or off.
- Changes from 1.16.1:
  * Bug fixes
- Changes from 1.16:
  * WouterTuinstra reimplemented support for dependencies and properly
    this time. He also improved error handling and reporting and added
    a couple of options improving the handling of references. The most
    important additions are the directive options :lift_description:,
    :lift_definitions:, :auto_target: and :auto_reference:. In addition
    to all that he also implemented support for the if, then and else
    keywords.
* Tue Jun 16 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.15:
  * Fixes for new sphinx releases
* Tue Jun 16 2020 Tomáš Chvátal <tchvatal@suse.com>
- Format with spec-cleaner
* Tue Sep 17 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v1.10
